<?php

    class Nagios_Plugin_Result_Condition extends Reactor_Condition
    {
        protected $tpl = 'nagios_plugin_result.php';
        protected $name = 'Nagios plugin return code matches';
		
		public static $registration = array(
			CONDITION_NAME => 'Nagios plugin result',
			CONDITION_CATEGORY => 'Network',
			CONDITION_DESCRIPTION => 'Runs a Nagios plugin and checks if the return code matches an expected value',
			CONDITION_AUTHOR => 'Mike Guthrie, Nagios Enterprises, LLC',
			CONDITION_VERSION => '1.0',
			CONDITION_DATE => '03/01/2013', //Last version update
			CONDITION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			CONDITION_TYPE => 'core', //core | user. core modules can't be deleted
			CONDITION_META => array('nagios_plugin_output','plugin_return_code'),	//Misc information	
		); 			
		
        protected $fields = array(
            'plugin' => array(
                'label' => 'plugin',
                'validate' => 'trim|required|xss_clean',
            ),
            'args' => array(
                'label' => 'args',
                'validate' => 'htmlentities',
            ),			
            'result' => array(
                'label' => 'result',
                'validate' => 'xss_clean|required|numeric',
            ),
        );

        public function get_label()
        {
            $params = $this->get_params();
			$str=implode(' ',$params);
			switch($params['result']){
				case 0:
					$rstr="OK";
					break;
				case 1:
					$rstr="WARNING";
					break;
				case 2:
					$rstr="CRITICAL";
					break;
				default:
					$rstr="UNKNOWN";
					break;
				}
			return sprintf('Nagios plugin command \'%s\' returns %s', $str,$rstr);
			
            //return parent::get_label();
        }
       
        public function run($context)
        {
			
			if(ENVIRONMENT=='development')
				logit("Running Nagios plugin condition...");
								
            $this->set_context($context);
            $params = $this->get_params();
			
			$file = $params['plugin'];
			$return = $params['result']; 
			$args = html_entity_decode($params['args']); 

			$cmd = $file." ".$args;
			if(ENVIRONMENT=='development')
				logit("CMD: $cmd");
			$out = exec($cmd,$arr,$code); 
			
			$this->set_context_var('nagios_plugin_output', implode("\n",$arr));
            $this->set_context_var('plugin_return_code',$code);
			
			if(ENVIRONMENT=='development')
				logit("Plugin output: ".$out);
			if($code==intval($return))
				$this->set_result(true);
			else
				$this->set_result(false);

        }
    }
